#!/bin/bash
# From a given list of labels, check which of them are already defined in the provided docker image; if any of the labels
# is not defined, a new image with the same name is generated with the label(s) added.
# Labels already defined are not modified.

if [ "$#" -ne 1 ]; then
    echo "Usage: $0 IMAGE_NAME"
    exit 1
fi

image_name="$1"

# list of labels to be enforced
declare -A enforced_labels=( ["com.jfrog.artifactory.retention.maxCount"]="10" ["com.jfrog.artifactory.retention.maxDays"]="7")

if ! docker inspect --type=image "$1" > /dev/null ; then
    echo "Error: image does not exist"
    exit 0
fi

# check if every label is defined
for label in "${!enforced_labels[@]}" ; do
    if ! docker inspect -f "{{json .Config.Labels }}" "$image_name" | jq -e '.['\""$label"\"']' > /dev/null ; then
        echo "Key not found"
        echo "$label = ${enforced_labels[$label]}"
        # add missing label to the arguments to be provided to `docker build`
        label_args+=" --label $label=\"${enforced_labels[$label]}\""
    fi
done

# generate new image
if [ -n "${label_args+x}" ]; then
    run_command="echo \"FROM $image_name\" | DOCKER_BUILDKIT=0 docker build $label_args -t $image_name --pull=false -"
    eval "$run_command"
fi
